import webpack from 'webpack'



export default {
  // Global page headers: https://go.nuxtjs.dev/config-head
  head: {
    script: [
      { src: 'https://static.nid.naver.com/js/naveridlogin_js_sdk_2.0.0.js' },
      { src: 'https://docs.opencv.org/3.4/opencv.js' },
    ],
    titleTemplate: 'Vridge AI - %s',
    title: 'Vridge AI',
    htmlAttrs: {
      lang: 'ko'
    },
    meta: [
      { charset: 'utf-8' },
      { name: 'viewport', content: 'width=device-width, initial-scale=1' },
      { hid: 'og:title', property: 'og:title', content: 'Vridge AI' },
      { hid: 'og:site_name', property: 'og:site_name', content: 'Vridge AI' },
      { hid: 'description', name: 'description', content: '클라우드 환경에서 인공지능 모델을 학습하고 배포 및 버전 관리 서비스' },
      { hid: 'og:image', property: 'og:image', content: 'https://d2q9yzkd471o7j.cloudfront.net/logo/head_logo.png?w=300&h=300' }
    ],
    link: [
      { rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' },
      { rel: 'preconnect', href: 'https://fonts.gstatic.com' },
      { rel: 'stylesheet', href: 'https://fonts.googleapis.com/css2?family=Noto+Sans+KR:wght@100;300;400;500;700;900&display=swap' },
      { rel: 'stylesheet', href: 'https://fonts.googleapis.com/earlyaccess/nanumgothic.css'},
      { rel: 'stylesheet', href: 'https://cdn.jsdelivr.net/npm/@mdi/font@6.5.95/css/materialdesignicons.min.css'},
    ]
  },

  // loading: '~/components/LoadingBar.vue',
  loading:false,

  // Global CSS: https://go.nuxtjs.dev/config-css
  css: [
    "~/assets/scss/common.scss",
    "~/assets/scss/transition.scss",
  ],

  // Plugins to run before rendering page: https://go.nuxtjs.dev/config-plugins
  plugins: [
    '~/plugins/global.js'
  ],

  // Auto import components: https://go.nuxtjs.dev/config-components
  components: true,

  // Modules for dev and build (recommended): https://go.nuxtjs.dev/config-modules
  buildModules: [
    // https://go.nuxtjs.dev/vuetify
    '@nuxtjs/vuetify',
    '@nuxtjs/svg'
  ],

  // Modules: https://go.nuxtjs.dev/config-modules
  modules: [
    '@nuxtjs/auth',
    '@nuxtjs/axios',
    '@nuxtjs/pwa',
    'nuxt-route-meta',
    ['cookie-universal-nuxt', { alias: 'cookiz' }],
    "vue2-editor/nuxt",
    'nuxt-healthcheck',
    'nuxt-i18n',
  ],

  // Vuetify module configuration: https://go.nuxtjs.dev/config-vuetify
  vuetify: {
    customVariables: ['~/assets/variables.scss'],
    treeShake: true,
    defaultAssets: {
      font: {
        family: 'Noto Sans KR'
      }
    }
  },

  animejs: true,

  // Build Configuration: https://go.nuxtjs.dev/config-build
  build: {
    vendor: ['axios'],
    hotMiddleware:{
      client:{
        quiet:true
      }
    },
    html: {
      minify: {
        collapseWhitespace: true,  // as @dario30186 mentioned
        removeComments: true, // 👈 add this line
      },
    },
    plugins: [
      new webpack.ProvidePlugin({
        // global modules
        $: 'jquery',
        jQuery: 'jquery',
        IScroll: 'iscroll',
        // _: 'lodash'
      })
    ],
    extend (config, ctx) {
      config.module.rules.push({
        enforce: 'pre',
        test: /\.txt$/,
        loader: 'raw-loader',
        exclude: /(node_modules)/
      });
    }
  },

  axios:{
    baseURL: 'http://localhost:5000'
  },
  
  healthCheck: {
    contentType: 'application/json',
    healthy: () => {
      return JSON.stringify({result: 'ok'})
    }
  },

  generate: {
    minify: {
      collapseWhitespace: false
    }
  }
}